@@ -20,6 +20,8 @@ classdef arduino < handle
   ## @deftypefnx {} {@var{retval} =} arduino (@var{port})
   ## @deftypefnx {} {@var{retval} =} arduino (@var{port}, @var{board})
   ## @deftypefnx {} {@var{retval} =} arduino (@var{port}, @var{board}[, [@var{propname}, @var{propvalue}]*)
+  ## @deftypefnx {} {@var{retval} =} arduino (@var{iaddress})
+  ## @deftypefnx {} {@var{retval} =} arduino (@var{ipaddress}, @var{board})
   ## Create a arduino object with a connection to an arduino board.
   ## 
   ## @subsubheading Inputs
@@ -80,6 +82,10 @@ classdef arduino < handle
     Board = "";
     Port = "";
   endproperties
+
+  properties (SetAccess = private, Hidden = true)
+    DeviceAddress = "";
+  endproperties
   
   methods (Access = public)
  
@@ -410,6 +416,10 @@ classdef arduino < handle
       v = this.config.port;
     endfunction
 
+    function v = get.DeviceAddress (this)
+      v = this.config.deviceaddress;
+    endfunction
+
   endmethods 
 endclassdef
 
